@@ -12,6 +12,7 @@ import (
 	kubeinformers "k8s.io/client-go/informers"
 	kubeset "k8s.io/client-go/kubernetes"
 	appsset "k8s.io/client-go/kubernetes/typed/apps/v1"
+	batchset "k8s.io/client-go/kubernetes/typed/batch/v1beta1"
 	coreset "k8s.io/client-go/kubernetes/typed/core/v1"
 	rbacset "k8s.io/client-go/kubernetes/typed/rbac/v1"
 	restclient "k8s.io/client-go/rest"
@@ -19,20 +20,20 @@ import (
 	"k8s.io/client-go/util/workqueue"
 	"k8s.io/klog"
 
+	configapiv1 "github.com/openshift/api/config/v1"
+	imageregistryv1 "github.com/openshift/api/imageregistry/v1"
 	operatorapi "github.com/openshift/api/operator/v1"
 	configset "github.com/openshift/client-go/config/clientset/versioned"
 	configsetv1 "github.com/openshift/client-go/config/clientset/versioned/typed/config/v1"
 	configinformers "github.com/openshift/client-go/config/informers/externalversions"
+	regopset "github.com/openshift/client-go/imageregistry/clientset/versioned"
+	regopinformers "github.com/openshift/client-go/imageregistry/informers/externalversions"
 	routeset "github.com/openshift/client-go/route/clientset/versioned"
 	routesetv1 "github.com/openshift/client-go/route/clientset/versioned/typed/route/v1"
 	routeinformers "github.com/openshift/client-go/route/informers/externalversions"
 
-	configapiv1 "github.com/openshift/api/config/v1"
-	imageregistryv1 "github.com/openshift/api/imageregistry/v1"
 	"github.com/openshift/cluster-image-registry-operator/defaults"
 	regopclient "github.com/openshift/cluster-image-registry-operator/pkg/client"
-	regopset "github.com/openshift/cluster-image-registry-operator/pkg/generated/clientset/versioned"
-	regopinformers "github.com/openshift/cluster-image-registry-operator/pkg/generated/informers/externalversions"
 	"github.com/openshift/cluster-image-registry-operator/pkg/parameters"
 	"github.com/openshift/cluster-image-registry-operator/pkg/resource"
 	"github.com/openshift/cluster-image-registry-operator/pkg/resource/object"
@@ -371,6 +372,11 @@ func (c *Controller) Run(stopCh <-chan struct{}) error {
 		return err
 	}
 
+	c.clients.Batch, err = batchset.NewForConfig(c.kubeconfig)
+	if err != nil {
+		return err
+	}
+
 	routeClient, err := routeset.NewForConfig(c.kubeconfig)
 	if err != nil {
 		return err
@@ -465,11 +471,26 @@ func (c *Controller) Run(stopCh <-chan struct{}) error {
 			c.listers.RegistryConfigs = informer.Lister()
 			return informer.Informer()
 		},
+		func() cache.SharedIndexInformer {
+			informer := regopInformerFactory.Imageregistry().V1().ImagePruners()
+			c.listers.ImagePrunerConfigs = informer.Lister()
+			return informer.Informer()
+		},
 		func() cache.SharedIndexInformer {
 			informer := configInformerFactory.Config().V1().Infrastructures()
 			c.listers.Infrastructures = informer.Lister()
 			return informer.Informer()
 		},
+		func() cache.SharedIndexInformer {
+			informer := kubeInformerFactory.Batch().V1beta1().CronJobs()
+			c.listers.CronJobs = informer.Lister().CronJobs(defaults.ImageRegistryOperatorNamespace)
+			return informer.Informer()
+		},
+		func() cache.SharedIndexInformer {
+			informer := kubeInformerFactory.Batch().V1().Jobs()
+			c.listers.Jobs = informer.Lister().Jobs(defaults.ImageRegistryOperatorNamespace)
+			return informer.Informer()
+		},
 	} {
 		informer := ctor()
 		informer.AddEventHandler(c.handler())
@@ -491,7 +512,7 @@ func (c *Controller) Run(stopCh <-chan struct{}) error {
 	regopInformerFactory.Start(stopCh)
 	routeInformerFactory.Start(stopCh)
 
-	// TODO(dmage): This controller should be started from main.
+	// TODO(dmage):This controller should be started from main.
 	go clusterOperatorStatusController.Run(stopCh)
 
 	klog.Info("waiting for informer caches to sync")
