@@ -1,16 +1,18 @@
 package resource
 
 import (
+	"fmt"
+
+	"github.com/openshift/cluster-image-registry-operator/defaults"
+	"github.com/openshift/cluster-image-registry-operator/pkg/parameters"
+	"github.com/openshift/cluster-image-registry-operator/pkg/storage"
+
+	imageregistryv1 "github.com/openshift/api/imageregistry/v1"
 	corev1 "k8s.io/api/core/v1"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 	"k8s.io/apimachinery/pkg/runtime"
 	coreset "k8s.io/client-go/kubernetes/typed/core/v1"
 	corelisters "k8s.io/client-go/listers/core/v1"
-
-	imageregistryv1 "github.com/openshift/api/imageregistry/v1"
-	"github.com/openshift/cluster-image-registry-operator/defaults"
-	"github.com/openshift/cluster-image-registry-operator/pkg/parameters"
-	"github.com/openshift/cluster-image-registry-operator/pkg/storage"
 )
 
 var _ Mutator = &generatorSecret{}
@@ -54,6 +56,10 @@ func (gs *generatorSecret) GetName() string {
 }
 
 func (gs *generatorSecret) expected() (runtime.Object, error) {
+	if gs.driver == nil {
+		return nil, fmt.Errorf("no storage driver present")
+	}
+
 	sec := &corev1.Secret{
 		ObjectMeta: metav1.ObjectMeta{
 			Name:      gs.GetName(),
@@ -61,11 +67,25 @@ func (gs *generatorSecret) expected() (runtime.Object, error) {
 		},
 	}
 
-	data, err := gs.driver.Secrets()
+	configenv, err := gs.driver.ConfigEnv()
 	if err != nil {
 		return nil, err
 	}
 
+	data, err := configenv.SecretData()
+	if err != nil {
+		return nil, err
+	}
+
+	volumesData, err := gs.driver.VolumeSecrets()
+	if err != nil {
+		return nil, err
+	}
+
+	for k, v := range volumesData {
+		data[k] = v
+	}
+
 	sec.StringData = data
 
 	return sec, nil
