@@ -5,6 +5,8 @@ import (
 	"net/http"
 	"testing"
 
+	"github.com/gophercloud/gophercloud"
+	"github.com/gophercloud/gophercloud/openstack/objectstorage/v1/containers"
 	th "github.com/gophercloud/gophercloud/testhelper"
 
 	corev1 "k8s.io/api/core/v1"
@@ -339,7 +341,9 @@ func TestSwiftSecrets(t *testing.T) {
 		},
 		Config: &config,
 	}
-	res, err := d.Secrets()
+	configenv, err := d.ConfigEnv()
+	th.AssertNoErr(t, err)
+	res, err := configenv.SecretData()
 	th.AssertNoErr(t, err)
 	th.AssertEquals(t, 2, len(res))
 	th.AssertEquals(t, username, res["REGISTRY_STORAGE_SWIFT_USERNAME"])
@@ -371,7 +375,9 @@ func TestSwiftSecrets(t *testing.T) {
 	fakeCloudsYAML = map[string][]byte{
 		cloudSecretKey: fakeCloudsYAMLData,
 	}
-	res, err = d.Secrets()
+	configenv, err = d.ConfigEnv()
+	th.AssertNoErr(t, err)
+	res, err = configenv.SecretData()
 	th.AssertNoErr(t, err)
 	th.AssertEquals(t, 2, len(res))
 	th.AssertEquals(t, username, res["REGISTRY_STORAGE_SWIFT_USERNAME"])
@@ -531,11 +537,11 @@ func TestSwiftConfigEnvCloudConfig(t *testing.T) {
 	th.AssertEquals(t, "REGISTRY_STORAGE_SWIFT_AUTHURL", res[2].Name)
 	th.AssertEquals(t, "http://localhost:5000/v3", res[2].Value)
 	th.AssertEquals(t, "REGISTRY_STORAGE_SWIFT_USERNAME", res[3].Name)
-	th.AssertEquals(t, true, res[3].ValueFrom != nil)
+	th.AssertEquals(t, true, res[3].Secret)
 	th.AssertEquals(t, "REGISTRY_STORAGE_SWIFT_PASSWORD", res[4].Name)
-	th.AssertEquals(t, true, res[4].ValueFrom != nil)
+	th.AssertEquals(t, true, res[4].Secret)
 	th.AssertEquals(t, "REGISTRY_STORAGE_SWIFT_AUTHVERSION", res[5].Name)
-	th.AssertEquals(t, "3", res[5].Value)
+	th.AssertEquals(t, 3, res[5].Value)
 	th.AssertEquals(t, "REGISTRY_STORAGE_SWIFT_DOMAIN", res[6].Name)
 	th.AssertEquals(t, domain, res[6].Value)
 	th.AssertEquals(t, "REGISTRY_STORAGE_SWIFT_TENANT", res[7].Name)
@@ -637,3 +643,203 @@ func TestSwiftEndpointTypeObjectStore(t *testing.T) {
 	th.AssertNoErr(t, err)
 	th.AssertEquals(t, true, res)
 }
+
+func TestSwiftIsAvailable(t *testing.T) {
+	th.SetupHTTP()
+	defer th.TeardownHTTP()
+
+	handleAuthentication(t, "object-store")
+
+	fakeCloudsYAMLData := []byte(`clouds:
+  ` + cloudName + `:
+    auth:
+      auth_url: ` + th.Endpoint() + "v3" + `
+      project_name: ` + tenant + `
+      username: ` + username + `
+      password: ` + password + `
+      domain_name: ` + domain + `
+    region_name: RegionOne`)
+
+	fakeCloudsYAML = map[string][]byte{
+		cloudSecretKey: fakeCloudsYAMLData,
+	}
+
+	th.Mux.HandleFunc("/", func(w http.ResponseWriter, r *http.Request) {
+		th.TestMethod(t, r, "GET")
+		w.Header().Set("Accept-Ranges", "bytes")
+		w.Header().Set("Accept", "application/json")
+		w.Header().Set("Content-Type", "application/json; charset=utf-8")
+		w.WriteHeader(http.StatusOK)
+
+		// Empty container list
+		w.Write([]byte("[]"))
+	})
+
+	// IsSwiftEnabled should return true in this case
+	listers := &regopclient.Listers{
+		Secrets:         MockIPISecretNamespaceLister{},
+		Infrastructures: fakeInfrastructureLister(cloudName),
+		OpenShiftConfig: MockConfigMapNamespaceLister{},
+	}
+	res, err := IsSwiftEnabled(listers)
+	th.AssertNoErr(t, err)
+	th.AssertEquals(t, true, res)
+}
+
+func TestSwiftIsNotAvailable(t *testing.T) {
+	th.SetupHTTP()
+	defer th.TeardownHTTP()
+	// Swift endpoint is not registered
+	handleAuthentication(t, "INVALID")
+
+	fakeCloudsYAMLData := []byte(`clouds:
+  ` + cloudName + `:
+    auth:
+      auth_url: ` + th.Endpoint() + "v3" + `
+      project_name: ` + tenant + `
+      username: ` + username + `
+      password: ` + password + `
+      domain_name: ` + domain + `
+    region_name: RegionOne`)
+
+	fakeCloudsYAML = map[string][]byte{
+		cloudSecretKey: fakeCloudsYAMLData,
+	}
+
+	th.Mux.HandleFunc("/"+container, func(w http.ResponseWriter, r *http.Request) {
+		th.TestMethod(t, r, "HEAD")
+		th.TestHeader(t, r, "Accept", "application/json")
+		w.Header().Set("Accept-Ranges", "bytes")
+		w.Header().Set("Content-Type", "application/json; charset=utf-8")
+		w.Header().Set("Date", "Wed, 17 Aug 2016 19:25:43 GMT")
+		w.Header().Set("X-Container-Bytes-Used", "100")
+		w.Header().Set("X-Container-Object-Count", "4")
+		w.Header().Set("X-Container-Read", "test")
+		w.Header().Set("X-Container-Write", "test2,user4")
+		w.Header().Set("X-Timestamp", "1471298837.95721")
+		w.Header().Set("X-Trans-Id", "tx554ed59667a64c61866f1-0057b4ba37")
+		w.Header().Set("X-Storage-Policy", "test_policy")
+		w.WriteHeader(http.StatusNoContent)
+	})
+
+	d, _ := mockConfig(false, th.Endpoint()+"v3", MockUPISecretNamespaceLister{})
+
+	_, err := d.getSwiftClient()
+	// if Swift endpoint is not registered, getSwiftClient should return *ErrEndpointNotFound
+	_, ok := err.(*gophercloud.ErrEndpointNotFound)
+	th.AssertEquals(t, true, ok)
+
+	// IsSwiftEnabled should return false in this case
+	listers := &regopclient.Listers{
+		Secrets:         MockIPISecretNamespaceLister{},
+		Infrastructures: fakeInfrastructureLister(cloudName),
+		OpenShiftConfig: MockConfigMapNamespaceLister{},
+	}
+	res, err := IsSwiftEnabled(listers)
+	th.AssertNoErr(t, err)
+	th.AssertEquals(t, false, res)
+}
+
+func TestNoPermissionsKeystone(t *testing.T) {
+	th.SetupHTTP()
+	defer th.TeardownHTTP()
+
+	handleAuthentication(t, "object-store")
+
+	fakeCloudsYAMLData := []byte(`clouds:
+  ` + cloudName + `:
+    auth:
+      auth_url: ` + th.Endpoint() + "v3" + `
+      project_name: ` + tenant + `
+      username: ` + username + `
+      password: ` + password + `
+      domain_name: ` + domain + `
+    region_name: RegionOne`)
+
+	fakeCloudsYAML = map[string][]byte{
+		cloudSecretKey: fakeCloudsYAMLData,
+	}
+
+	th.Mux.HandleFunc("/", func(w http.ResponseWriter, r *http.Request) {
+		th.TestMethod(t, r, "GET")
+		w.Header().Set("Accept-Ranges", "bytes")
+		w.Header().Set("Accept", "application/json")
+		w.Header().Set("Content-Type", "application/json; charset=utf-8")
+
+		// Swift returns 403 because the user doesn't have required permissions
+		w.WriteHeader(http.StatusForbidden)
+	})
+
+	d, _ := mockConfig(false, th.Endpoint()+"v3", MockUPISecretNamespaceLister{})
+
+	conn, err := d.getSwiftClient()
+	th.AssertNoErr(t, err)
+
+	// if the user doesn't have permissions, gophercloud should return ErrDefault403
+	listOpts := containers.ListOpts{Full: false}
+	_, err = containers.List(conn, listOpts).AllPages()
+	_, ok := err.(gophercloud.ErrDefault403)
+	th.AssertEquals(t, true, ok)
+
+	// IsSwiftEnabled should return false in this case
+	listers := &regopclient.Listers{
+		Secrets:         MockIPISecretNamespaceLister{},
+		Infrastructures: fakeInfrastructureLister(cloudName),
+		OpenShiftConfig: MockConfigMapNamespaceLister{},
+	}
+	res, err := IsSwiftEnabled(listers)
+	th.AssertNoErr(t, err)
+	th.AssertEquals(t, false, res)
+}
+
+func TestNoPermissionsSwauth(t *testing.T) {
+	th.SetupHTTP()
+	defer th.TeardownHTTP()
+
+	handleAuthentication(t, "object-store")
+
+	fakeCloudsYAMLData := []byte(`clouds:
+  ` + cloudName + `:
+    auth:
+      auth_url: ` + th.Endpoint() + "v3" + `
+      project_name: ` + tenant + `
+      username: ` + username + `
+      password: ` + password + `
+      domain_name: ` + domain + `
+    region_name: RegionOne`)
+
+	fakeCloudsYAML = map[string][]byte{
+		cloudSecretKey: fakeCloudsYAMLData,
+	}
+
+	th.Mux.HandleFunc("/", func(w http.ResponseWriter, r *http.Request) {
+		th.TestMethod(t, r, "GET")
+		w.Header().Set("Accept-Ranges", "bytes")
+		w.Header().Set("Accept", "application/json")
+		w.Header().Set("Content-Type", "application/json; charset=utf-8")
+
+		// Swift returns 401 when the client tries to get the response schema
+		w.WriteHeader(http.StatusUnauthorized)
+	})
+
+	d, _ := mockConfig(false, th.Endpoint()+"v3", MockUPISecretNamespaceLister{})
+
+	conn, err := d.getSwiftClient()
+	th.AssertNoErr(t, err)
+
+	// if the user doesn't have permissions, gophercloud should return ErrDefault401
+	listOpts := containers.ListOpts{Full: false}
+	_, err = containers.List(conn, listOpts).AllPages()
+	_, ok := err.(gophercloud.ErrDefault401)
+	th.AssertEquals(t, true, ok)
+
+	// IsSwiftEnabled should return false in this case
+	listers := &regopclient.Listers{
+		Secrets:         MockIPISecretNamespaceLister{},
+		Infrastructures: fakeInfrastructureLister(cloudName),
+		OpenShiftConfig: MockConfigMapNamespaceLister{},
+	}
+	res, err := IsSwiftEnabled(listers)
+	th.AssertNoErr(t, err)
+	th.AssertEquals(t, false, res)
+}
